# [Zope-tests] OK : winbot / ztk_dev py_270_win64

buildbot at winbot.zope.org buildbot at winbot.zope.org
Thu Feb 3 15:51:25 EST 2011

- Previous message: [Zope-tests] OK : winbot / ztk_dev py_270_win32
- Next message: [Zope-tests] OK : winbot / ztk_10 py_244_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : winbot / ztk_dev py_270_win64
    Build: http://winbot.zope.org/builders/ztk_dev%20py_270_win64/builds/140

    Build Reason: The Nightly scheduler named 'ztk_dev py_270_win64_nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://winbot.zope.org/

- Previous message: [Zope-tests] OK : winbot / ztk_dev py_270_win32
- Next message: [Zope-tests] OK : winbot / ztk_10 py_244_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list